@@ -23,7 +23,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
 from saharaclient.api import base
-from saharaclient.osc.v1 import utils
+from saharaclient.osc import utils
 
 JOB_BINARY_FIELDS = ['name', 'id', 'url', 'description', 'is_public',
                      'is_protected']
@@ -506,7 +506,7 @@ class DownloadJobBinary(command.Command):
                 client.job_binaries, parsed_args.job_binary)
             data = client.job_binaries.get_file(jb_id)
 
-            with open(parsed_args.file, 'w') as f:
+            with open(parsed_args.file, 'wb') as f:
                 f.write(data)
             sys.stdout.write(
                 'Job binary "{jb}" has been downloaded '
